fn switch_off_heater(
mutex_device_scheduler_heating: &Arc<Mutex<i32>>,
mutex_blocked_during_actuation: &mut bool,
heating_channels: &mut HeatingChannels,
)Expand description
Commands the relay manager to switch off the heater.
This function is a specific wrapper around actuate_heater that sends the SwitchOff command.
Arguments
mutex_device_scheduler_heating- A reference to the shared actuation mutex.mutex_blocked_during_actuation- A mutable flag to track if the actuation mutex was blocked.heating_channels- A mutable reference to the struct containing the channels.